pygeodesy.hausdorff.HausdorffKarney

Package pygeodesy :: Module hausdorff :: Class HausdorffKarney |
[frames] | no frames]

# Class HausdorffKarney

      object --+
               |
    named._Named --+
                   |
           Hausdorff --+
                       |
                      HausdorffKarney

Compute the `Hausdorff` distance with Karney's geographiclib geodesic.Geodesic`.Inverse` method.

Instance Methods
__init__(self, point1s, datum=None, **seed_name__wrap) New HausdorffKarney calculator. |
Inherited from `Hausdorff`: `directed`, `distance`, `point`, `symmetric` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Hausdorff`: `adjust`, `datum`, `kwds`, `seed`, `units`, `wrap` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, point1s, datum=None, **seed_name__wrap) (Constructor) |
New HausdorffKarney calculator. Arguments: `datum` - Datum to override the default `Datums.WGS84` and first `knots`' datum (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple). `seed_name__wrap` - Optional `seed=None` and `name=NN` and keyword arguments for method `Inverse1` of class geodesicw.Geodesic. Raises: `ImportError` - Package geographiclib missing. `TypeError` - Invalid `datum`. Overrides: object.__init__ See Also: Hausdorff.__init__ for details about `point1s`, `seed`, `name` and other exceptions.